@@ -39,7 +39,6 @@
 
 #ifdef HAVE_ESD
 static char *esound_hostname = NULL;
-static gboolean esound_hostname_null_ok = FALSE;
 static int gnome_sound_connection = -1;
 #endif
 
@@ -76,7 +75,7 @@ WAVFormatChunk;
 /**
  * gnome_sound_sample_load_wav:
  * @file: filename to try loading a WAV file from.
- * 
+ *
  * Used to load a .wav file into esound.
  *
  * Returns a GnomeSoundSample or NULL if file did not exist.
@@ -284,8 +283,7 @@ gnome_sound_sample_load_wav(const char *file)
     }
   fclose (f);
   g_free (s);
-  if (s->data)
-    g_free (s->data);
+  g_free (s->data);
 
   return NULL;
 }
@@ -300,16 +298,13 @@ static gboolean
 use_sound (void)
 {
   if (gnome_sound_connection == -1){
-    if (esound_hostname || esound_hostname_null_ok){
       gnome_sound_connection = esd_open_sound (esound_hostname);
       if (gnome_sound_connection == -1){
 	g_free (esound_hostname);
 	esound_hostname = NULL;
-	esound_hostname_null_ok = FALSE;
 	return FALSE;
       }
     }
-  }
   return TRUE;
 }
 #endif
@@ -385,7 +380,7 @@ gnome_sound_sample_load_audiofile(const char *file)
     s = NULL;
     goto error_case;
   }
-  
+
   frames_read = afReadFrames(in_file, AF_DEFAULT_TRACK, s->data,
 			     frame_count * in_channels);
 
@@ -448,7 +443,7 @@ gnome_sound_sample_load(const char *sample_name, const char *filename)
     {
       if (s->data)
 	{
-	  /* "name" of all samples is currently "E", should be name of sound 
+	  /* "name" of all samples is currently "E", should be name of sound
 	   * file, or event type, for later identification */
 	  s->id = esd_sample_cache (gnome_sound_connection, s->format, s->rate,
 				    size, (char *)sample_name);
@@ -481,7 +476,7 @@ gnome_sound_sample_load(const char *sample_name, const char *filename)
  * Plays the audio stored in @filename, if possible. Fail quietly if playing is
  * not possible (due to missing sound support or for other reasons).
  */
-void 
+void
 gnome_sound_play (const char * filename)
 {
 #ifdef HAVE_ESD
@@ -497,7 +492,7 @@ gnome_sound_play (const char * filename)
 
   g_snprintf(buf, sizeof(buf), "%d-%u-%d",
 	     getpid(), cookie++, rand ());
- 
+
   /* overflow, make sure we don't reinit with rand again */
   if (cookie == 0)
 	  cookie = 1;
@@ -522,14 +517,13 @@ gnome_sound_init(const char *hostname)
 #ifdef HAVE_ESD
 	srand(time(NULL));
 	g_free (esound_hostname);
+	esound_hostname = NULL;
 	if (hostname)
 		esound_hostname = g_strdup (hostname);
-	else
-		esound_hostname_null_ok = TRUE;
 #endif
 }
 
-/** 
+/**
  * gnome_sound_shutdown:
  *
  * Shuts down the gnome sound support.
@@ -540,6 +534,7 @@ gnome_sound_shutdown(void)
 #ifdef HAVE_ESD
 	g_free (esound_hostname);
 	esound_hostname = NULL;
+
 	if(gnome_sound_connection >= 0){
 		esd_close(gnome_sound_connection);
 		gnome_sound_connection = -1;
@@ -547,7 +542,7 @@ gnome_sound_shutdown(void)
 #endif
 }
 
-/** 
+/**
  * gnome_sound_connection_get:
  *
  * Rarely needed to by programs directly, this function may be useful if a
